pub struct Ctx {
pub block_id: u16,
pub is_compiling_recursive: bool,
pub single_run: bool,
pub file_idx: u16,
pub offset: u16,
}Fields
block_id: u16is_compiling_recursive: boolWhether the code being compiled is within a recursive function
single_run: boolWhether the code being compiled is guaranteed to run at most once
file_idx: u16Index of the current file in State’s sources
offset: u16Instruction offset that’s only used when compiling a function
Implementations
Sourceimpl Ctx
impl Ctx
pub const fn no_single_run(self) -> Self
pub const fn advance_offset(self, output_len: u16) -> Self
pub const fn set_offset(self, offset: u16) -> Self